Processor.App.OutStreamer.dummy\_streamer.DummyStreamer.clean\_up
=================================================================

.. currentmodule:: Processor.App.OutStreamer.dummy_streamer

.. automethod:: DummyStreamer.clean_up